
# Slot: verbose


Whether to show a loading bar while reading the files. Note that, if parallel loading is enabled, loading bars will not be showed because they are a synchronization bottleneck.

URI: [https://w3id.org/neat/ensmallenRunConfig__verbose](https://w3id.org/neat/ensmallenRunConfig__verbose)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
